@@ -251,6 +251,37 @@ void init_object(py::module_ &m)
                 return self.getOwningQPDF() == other.getOwningQPDF();
             },
             "Test if two objects are owned by the same :class:`pikepdf.Pdf`.")
+        .def(
+            "with_same_owner_as",
+            [](QPDFObjectHandle &self, QPDFObjectHandle &other) {
+                QPDF *self_owner  = self.getOwningQPDF();
+                QPDF *other_owner = other.getOwningQPDF();
+
+                if (self_owner == other_owner)
+                    return self;
+                if (!other_owner)
+                    throw py::value_error(
+                        "with_same_owner_as() called for object that has no owner");
+                if (!self.isIndirect())
+                    return other_owner->makeIndirectObject(self);
+
+                auto self_in_other = other_owner->copyForeignObject(self);
+                return self_in_other;
+            },
+            R"~~~(
+                Returns an object that is owned by the same Pdf that owns the *other* object.
+
+                If the objects already have the same owner, this object is returned.
+                If the *other* object has a different owner, then a copy is created
+                that is owned by *other*'s owner. If this object is a direct object
+                (no owner), then an indirect object is created that is owned by
+                *other*. An exception is thrown if *other* is a direct object.
+
+                This method may be convenient when a reference to the Pdf is not
+                available.
+
+                ..versionadded:: 2.14
+            )~~~")
         .def_property_readonly("is_indirect", &QPDFObjectHandle::isIndirect)
         .def("__repr__", &objecthandle_repr)
         .def("__hash__",
@@ -273,11 +304,14 @@ void init_object(py::module_ &m)
                 }
                 throw std::logic_error("don't know how to hash this"); // LCOV_EXCL_LINE
             })
-        .def("__eq__",
+        .def(
+            "__eq__",
             [](QPDFObjectHandle &self, QPDFObjectHandle &other) {
                 return (self == other); // overloaded
-            })
-        .def("__eq__",
+            },
+            py::is_operator())
+        .def(
+            "__eq__",
             [](QPDFObjectHandle &self, py::str other) {
                 std::string utf8_other = other.cast<std::string>();
                 switch (self.getTypeCode()) {
@@ -288,19 +322,25 @@ void init_object(py::module_ &m)
                 default:
                     return false;
                 }
-            })
-        .def("__eq__",
+            },
+            py::is_operator())
+        .def(
+            "__eq__",
             [](QPDFObjectHandle &self, py::object other) -> py::object {
                 QPDFObjectHandle q_other;
                 try {
                     q_other = objecthandle_encode(other);
                 } catch (const py::cast_error &) {
+                    // Cannot remove this construct without reaching into pybind11
+                    // internals - reason being that we don't automatically convert
+                    // py::object to handle, so pybind11 doesn't know that we tried.
                     return py::reinterpret_borrow<py::object>(
                         py::handle(Py_NotImplemented));
                 }
                 bool result = (self == objecthandle_encode(other));
                 return py::bool_(result);
-            })
+            },
+            py::is_operator())
         .def("__copy__", [](QPDFObjectHandle &h) { return h.shallowCopy(); })
         .def("__len__",
             [](QPDFObjectHandle &h) {
@@ -631,23 +671,36 @@ void init_object(py::module_ &m)
         .def(
             "page_contents_add",
             [](QPDFObjectHandle &h, QPDFObjectHandle &contents, bool prepend) {
+                deprecation_warning(
+                    "pikepdf.Object.page_contents_add is deprecated; use "
+                    "pikepdf.Page.contents_add instead");
                 if (!h.isPageObject())
                     throw py::type_error("Not a Page");
+
                 h.addPageContents(contents, prepend);
             },
-            "Append or prepend to an existing page's content stream.",
+            R"~~~(
+            Append or prepend to an existing page's content stream.
+
+            .. deprecated:: 2.14
+                Use :meth:`pikepdf.Page.contents_add` instead.
+            )~~~",
             py::arg("contents"),
             py::arg("prepend") = false,
             py::keep_alive<1, 2>())
-        .def("page_contents_coalesce",
-            &QPDFObjectHandle::coalesceContentStreams,
+        .def(
+            "page_contents_coalesce",
+            [](QPDFObjectHandle &h) {
+                deprecation_warning(
+                    "pikepdf.Object.page_contents_coalesce is deprecated; use "
+                    "pikepdf.Page.contents_coalesce instead");
+                return h.coalesceContentStreams();
+            },
             R"~~~(
             Coalesce an array of page content streams into a single content stream.
 
-            The PDF specification allows the ``/Contents`` object to contain either
-            an array of content streams or a single content stream. However, it
-            simplifies parsing and editing if there is only a single content stream.
-            This function merges all content streams.
+            .. deprecated:: 2.14
+                Use :meth:`pikepdf.Page.contents_coalesce` instead.
             )~~~")
         .def_property_readonly("_objgen", &object_get_objgen)
         .def_property_readonly("objgen",
@@ -823,5 +876,4 @@ void init_object(py::module_ &m)
     m.def("unparse", [](py::object obj) -> py::bytes {
         return objecthandle_encode(obj).unparseBinary();
     });
-
 } // init_object
